use discord_webhook_rs::Webhook;
use regex::Regex;
use std::env;
use time::macros::format_description;
use time::{Date, OffsetDateTime, UtcOffset};

fn main() {
    dotenvy::dotenv().expect("Need a .env file");

    let doc_url = env::var("DOC_URL").expect("Missing DOC_URL in .env");
    let webhook = env::var("WEBHOOK_URL").expect("Missing WEBHOOK_URL in .env");

    let body = reqwest::blocking::get(doc_url + "/export?gid=0&format=txt")
        .unwrap()
        .text()
        .expect("Google doc download failed!")
        .replace("\r\n", "\n"); // Normalize line endings

    let announcement_matcher = Regex::new(r"(\w+day,? \w+ \d+) *((?:.|\n)+?)\n\w+day").unwrap();

    let last_announcement = announcement_matcher.captures_iter(&body).next().unwrap();

    let date = last_announcement.get(1).unwrap().as_str().replace(",", "");

    dbg!(&date);

    let announcements = last_announcement
        .get(2)
        .unwrap()
        .as_str()
        .trim()
        .to_string();

    // println!("{}", announcements);

    let pretty_announcements = Regex::new(r"\n+")
        .unwrap()
        .replace_all(&announcements, "\n")
        .to_string();

    // println!("{}", pretty_announcements);

    let description = &format_description!("[weekday] [month repr:long] [day padding:none] [year]");
    let parsed_date =
        Date::parse(&format!("{} 2025", date), description).expect("Date parse failed!");
    println!("Date: {:}", parsed_date);

    if OffsetDateTime::now_utc()
        .to_offset(UtcOffset::from_hms(-5, 0, 0).unwrap())
        .date()
        != parsed_date
    {
        println!("Last date is not today!");
        return;
    }

    Webhook::new(webhook)
        .content(&format!("## {}:\n{}", date, pretty_announcements))
        .send()
        .unwrap();
}
